==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/zh_TW.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "檢視器",
    "Simple file viewer with slideshow for media" : "簡單的檔案檢視器，支援媒體幻燈片檢視",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "以電影的形式顯示您最新的假日照片與影片，直接從您的 Nextcloud 看看您最新的小說，借助您最愛的檔案與更多東西的直接預覽，選取最佳的 GIF！",
    "Your browser does not support audio." : "您的瀏覽器不支援音訊。",
    "Error loading {name}" : "載入 {name} 錯誤",
    "Unsaved changes" : "未儲存變更",
    "Drop changes" : "放棄變更",
    "Your browser does not support videos." : "您的瀏覽器不支援視訊。",
    "Edit" : "編輯",
    "Open sidebar" : "開啟側邊攔",
    "Download" : "下載",
    "Delete" : "刪除",
    "There is no plugin available to display this file type" : "沒有可以顯示這個檔案類型的外掛",
    "View" : "檢視",
    "Name" : "名稱",
    "Save" : "儲存",
    "Save as" : "另存新檔",
    "Back" : "返回",
    "Loading …" : "正在載入……",
    "Reset" : "重設",
    "All changes will be lost." : "所有變更都將會遺失。",
    "Are you sure you want to continue?" : "您確定您想要繼續嗎？",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "Undo" : "復原",
    "Redo" : "重作",
    "Show original image" : "顯示原始影像",
    "Zoom in" : "放大",
    "Zoom out" : "縮小",
    "Toggle zoom menu" : "切換縮放選單",
    "Adjust" : "調整",
    "Fine-tune" : "微調",
    "Filters" : "過濾",
    "Watermark" : "水印",
    "Draw" : "繪圖",
    "Resize" : "調整大小",
    "Invalid image." : "無效的圖片。",
    "Error while uploading the image." : "上傳圖片時發生錯誤。",
    "are not images" : "不是圖片",
    "is not an image" : "不是圖片",
    "to be uploaded" : "待上傳",
    "Crop" : "裁剪",
    "Original" : "原始",
    "Custom" : "自訂",
    "Square" : "方形",
    "Landscape" : "風景",
    "Portrait" : "人像",
    "Ellipse" : "橢圓",
    "Classic TV" : "經典電視",
    "CinemaScope" : "電影放映機",
    "Arrow" : "箭頭",
    "Blur" : "模糊",
    "Brightness" : "亮度",
    "Contrast" : "對比",
    "Un-flip X" : "取消翻轉 X",
    "Flip X" : "翻轉 X",
    "Un-flip Y" : "取消翻轉 Y",
    "Flip Y" : "翻轉 Y",
    "HSV" : "HSV",
    "Hue" : "色相",
    "Saturation" : "飽和度",
    "Value" : "明度",
    "Image" : "圖片",
    "Importing …" : "正在匯入……",
    "+ Add image" : "+ 新增圖片",
    "Line" : "線段",
    "Pen" : "筆",
    "Polygon" : "多邊形",
    "Sides" : "邊",
    "Rectangle" : "矩形",
    "Corner Radius" : "圓角半徑",
    "Width in pixels" : "像素寬度",
    "Height in pixels" : "像素高度",
    "Toggle ratio lock" : "切換比例鎖定",
    "Reset to original image size" : "重設為原始圖片大小",
    "Rotate" : "旋轉",
    "Text" : "文字",
    "Text spacing" : "文字間距",
    "Text alignment" : "文字對齊",
    "Font family" : "字型家族",
    "Size" : "大小",
    "Letter spacing" : "字母間距",
    "Line height" : "行高",
    "Warmth" : "溫暖",
    "+ Add watermark" : "+ 新增水印",
    "Choose watermark type" : "選擇水印類型",
    "Upload watermark" : "上傳水印",
    "Add as text" : "新增為留言",
    "Padding" : "填充",
    "Shadow" : "陰影",
    "Horizontal" : "水平",
    "Vertical" : "垂直",
    "Opacity" : "不透明度",
    "Position" : "位置",
    "Stroke" : "筆劃",
    "Save image as" : "儲存圖片為",
    "Extension" : "副檔名",
    "Name is required." : "名稱為必填。",
    "Quality" : "品質",
    "Saved image size (width x height)" : "儲存的圖片大小（寬度 x 高度）",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "請注意，選定的裁剪區域低於套用的調整大小，這可能會導致品質下降",
    "Actual size (100%)" : "實際大小 (100%)",
    "Fit size" : "合適大小"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.8.tgz: nextcloud/apps/viewer/l10n/zh_TW.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "檢視器",
    "Simple file viewer with slideshow for media" : "簡單的檔案檢視器，支援媒體幻燈片檢視",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "以電影的形式顯示您最新的假日照片與影片，直接從您的 Nextcloud 看看您最新的小說，借助您最愛的檔案與更多東西的直接預覽，選取最佳的 GIF！",
    "Your browser does not support audio." : "您的瀏覽器不支援音訊。",
    "Error loading {name}" : "載入 {name} 錯誤",
    "Image saved" : "圖片已儲存",
    "Error saving image" : "儲存影像時發生錯誤",
    "Unsaved changes" : "未儲存變更",
    "Drop changes" : "放棄變更",
    "Content of \"{fileName}\"" : "「{fileName}」的內容",
    "Your browser does not support videos." : "您的瀏覽器不支援視訊。",
    "Edit" : "編輯",
    "Open sidebar" : "開啟側邊攔",
    "Download" : "下載",
    "Delete" : "刪除",
    "There is no plugin available to display this file type" : "沒有可以顯示這個檔案類型的外掛",
    "View" : "檢視",
    "Name" : "名稱",
    "Save" : "儲存",
    "Save as" : "另存新檔",
    "Back" : "返回",
    "Loading …" : "正在載入……",
    "Reset" : "重設",
    "All changes will be lost." : "所有變更都將會遺失。",
    "Are you sure you want to continue?" : "您確定您想要繼續嗎？",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "Undo" : "復原",
    "Redo" : "重作",
    "Show original image" : "顯示原始影像",
    "Zoom in" : "放大",
    "Zoom out" : "縮小",
    "Toggle zoom menu" : "切換縮放選單",
    "Adjust" : "調整",
    "Fine-tune" : "微調",
    "Filters" : "過濾",
    "Watermark" : "水印",
    "Draw" : "繪圖",
    "Resize" : "調整大小",
    "Invalid image." : "無效的圖片。",
    "Error while uploading the image." : "上傳圖片時發生錯誤。",
    "are not images" : "不是圖片",
    "is not an image" : "不是圖片",
    "to be uploaded" : "待上傳",
    "Crop" : "裁剪",
    "Original" : "原始",
    "Custom" : "自訂",
    "Square" : "方形",
    "Landscape" : "風景",
    "Portrait" : "人像",
    "Ellipse" : "橢圓",
    "Classic TV" : "經典電視",
    "CinemaScope" : "電影放映機",
    "Arrow" : "箭頭",
    "Blur" : "模糊",
    "Brightness" : "亮度",
    "Contrast" : "對比",
    "Un-flip X" : "取消翻轉 X",
    "Flip X" : "翻轉 X",
    "Un-flip Y" : "取消翻轉 Y",
    "Flip Y" : "翻轉 Y",
    "HSV" : "HSV",
    "Hue" : "色相",
    "Saturation" : "飽和度",
    "Value" : "明度",
    "Image" : "圖片",
    "Importing …" : "正在匯入……",
    "+ Add image" : "+ 新增圖片",
    "Line" : "線段",
    "Pen" : "筆",
    "Polygon" : "多邊形",
    "Sides" : "邊",
    "Rectangle" : "矩形",
    "Corner Radius" : "圓角半徑",
    "Width in pixels" : "像素寬度",
    "Height in pixels" : "像素高度",
    "Toggle ratio lock" : "切換比例鎖定",
    "Reset to original image size" : "重設為原始圖片大小",
    "Rotate" : "旋轉",
    "Text" : "文字",
    "Text spacing" : "文字間距",
    "Text alignment" : "文字對齊",
    "Font family" : "字型家族",
    "Size" : "大小",
    "Letter spacing" : "字母間距",
    "Line height" : "行高",
    "Warmth" : "溫暖",
    "+ Add watermark" : "+ 新增水印",
    "Choose watermark type" : "選擇水印類型",
    "Upload watermark" : "上傳水印",
    "Add as text" : "新增為留言",
    "Padding" : "填充",
    "Shadow" : "陰影",
    "Horizontal" : "水平",
    "Vertical" : "垂直",
    "Opacity" : "不透明度",
    "Position" : "位置",
    "Stroke" : "筆劃",
    "Save image as" : "儲存圖片為",
    "Extension" : "副檔名",
    "Name is required." : "名稱為必填。",
    "Quality" : "品質",
    "Saved image size (width x height)" : "儲存的圖片大小（寬度 x 高度）",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "請注意，選定的裁剪區域低於套用的調整大小，這可能會導致品質下降",
    "Actual size (100%)" : "實際大小 (100%)",
    "Fit size" : "合適大小",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "以電影的形式顯示您最新的假日照片與影片，直接從您的 Nextcloud 看看您最新的小說，借助您最愛的檔案與更多東西的直接預覽，選取最佳的 GIF！"
},
"nplurals=1; plural=0;");
